@@ -65,6 +65,11 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('agent/tunnel_types').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
+        with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
+        with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(['<SERVICE DEFAULT>'])
     end
 
     it 'installs neutron ovs agent package' do
@@ -318,6 +323,23 @@ describe 'neutron::agents::ml2::ovs' do
 
       it { should raise_error(Puppet::Error, /Enabling DPDK without manage vswitch does not have any effect/) }
     end
+
+    context 'when parameters for resource providers are set' do
+      before :each do
+        params.merge!(
+          :resource_provider_bandwidths  => ['provider-a', 'provider-b'],
+          :resource_provider_hypervisors => ['provider-a:compute-a', 'provider-b:compute-b'],
+        )
+      end
+
+      it 'configures resource providers' do
+        should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
+          with_value('provider-a,provider-b')
+        should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
+          with_value('provider-a:compute-a,provider-b:compute-b')
+      end
+    end
+
   end
 
   shared_examples 'neutron::agents::ml2::ovs on Debian' do
@@ -368,6 +390,16 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'with direct output enabled for egress flows' do
+      before :each do
+        params.merge!(:explicitly_egress_direct => true)
+      end
+
+      it 'configure neutron/plugins/ml2/ml2_conf.ini' do
+        should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(true)
+      end
+    end
+
   end
 
   on_supported_os({
